@@ -1,33 +1,24 @@
 /*
-    Copyright 2012 Viranch Mehta <viranch.mehta@gmail.com>
+    SPDX-FileCopyrightText: 2012 Viranch Mehta <viranch.mehta@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "canvaswidget.h"
+
+// own
 #include "globals.h"
 #include "kbreakout_debug.h"
 #include "settings.h"
-
+// KDEGames
+#include <KgThemeProvider>
+// Qt
 #include <QGraphicsObject>
 #include <QAction>
 #include <QCursor>
 #include <QStandardPaths>
 #include <QQuickItem>
 
-#include <KgThemeProvider>
-
 CanvasWidget::CanvasWidget(QWidget *parent) :
     KgDeclarativeView(parent),
     m_provider(new KgThemeProvider)
@@ -159,6 +150,6 @@ void CanvasWidget::resetMousePosition()
 
 void CanvasWidget::focusOutEvent(QFocusEvent *event)
 {
-    emit focusLost();
+    Q_EMIT focusLost();
     QQuickWidget::focusOutEvent(event);
 }
